@@ -6,6 +6,7 @@ from cameo_claw.cameo_claw_reuse import bytesio_to_gzip, requests_get_write, \
     bytesio_filename, write_gzip, read_csv_distinct
 from cameo_claw.functional import it_mp_f
 import polars as pl
+import pandas as pd
 
 
 def a_download(url, target_directory):
@@ -81,39 +82,32 @@ def it_filter(lst_url, target_directory, lst_distinct_column, lst_column_match,
 
 def a_chunk(url, target_directory, lst_distinct_column, lst_column_match=[], sort_column=''):
     def write(bytes1):
-        print('111')
-        df = read_csv_distinct(bytes1, lst_distinct_column)
-        print('112')
+        # 2022-04-10 06:21
+        # use polars hang at FastAPI+Python 3.7
+        # use polars hang at FastAPI+replit Python 3.8.12
+        # use polars OK at FastAPI+Mac Python 3.8.9
+        df = pd.read_csv(BytesIO(bytes1), compression='gzip')
+        df = df.drop_duplicates(subset=lst_distinct_column)
+
+        # pandas column equals example
+        # rslt_df = dataframe[(dataframe['Age'] == 22) &
+        #                     dataframe['Stream'].isin(options)]
         condition = ''
-        print('113')
         for lst_col_val in lst_column_match:
-            print('114')
-            condition += f"""(pl.col('{lst_col_val[0]}')=='{lst_col_val[1]}') | """
-        print('115')
+            condition += f"""(df['{lst_col_val[0]}']=='{lst_col_val[1]}') | """
         condition = condition[:-3]
-        print('116')
-        df = df.filter(eval(condition))
-        print('117')
+        df = df[eval(condition)]
+
         if sort_column:
-            df = df.sort(sort_column)
-        print('118')
-        bytesio_csv = BytesIO()
-        print('122')
-        df.to_csv(bytesio_csv, has_header=False)
-        print('123')
-        bytesio_gz = BytesIO()
-        print('124')
-        with gzip.open(bytesio_gz, 'wb') as f:
-            print('125')
-            f.write(bytesio_csv.getvalue())
-        print('126')
-        return bytesio_gz.getvalue()
+            df = df.sort_values(by=[sort_column])
+        bytesio = BytesIO()
+        df.to_csv(bytesio, header=False, index=False, compression='gzip')
+        return bytesio.getvalue()
 
     return requests_get_write(target_directory, url, write)
 
 
 def it_chunk(lst_url, target_directory, lst_distinct_column, lst_column_match, sort_column):
-    print('127')
     return it_mp_f(a_chunk,
                    [tuple([url, target_directory, lst_distinct_column,
                            lst_column_match, sort_column]) for url in lst_url])
